<template>
  <div>
    <div ref="editor" style="text-align: left;"></div>
  </div>
</template>

<script>
import E from 'wangeditor';

export default {
  name: 'WangEditor',
  data() {
    return {
      editor: null, // WangEditor 实例
    };
  },
  props: {
    content: {
      type: String,
      default: ''
    }
  },
  watch: {
    // 当父组件传入的 content 变化时，更新编辑器内容
    content(newContent) {
      if (this.editor && newContent !== this.editor.txt.html()) {
        this.editor.txt.html(newContent);
      }
    }
  },
  mounted() {
    // 初始化 WangEditor
    this.editor = new E(this.$refs.editor);
    this.editor.config.onchange = () => {
      // 编辑器内容变化时，触发 input 事件传递给父组件
      this.$emit('input', this.editor.txt.html());
    };
    // 配置菜单和其他设置
    this.editor.config.menus = [
      'head', 'bold', 'italic', 'underline', 'image', 'link', 'list', 'undo', 'redo'
    ];
    this.editor.config.zIndex = 1000;
    // 创建编辑器
    this.editor.create();
    // 设置初始内容
    if (this.content) {
      this.editor.txt.html(this.content);
    }
  },
  beforeDestroy() {
    // 销毁编辑器实例，释放资源
    if (this.editor) {
      this.editor.destroy();
    }
  }
};
</script>
